        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 31 <br>4,6,7,8,9,10,11,13,15,16,17,18,20,22,23,24,27,31,33,34,35,36,38,39,40,43,44,46,47,49,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260627 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>26</strong> miembros: 20 <strong>control</strong><br>0,1,2,3,5,12,14,19,21,25,26,28,29,30,32,37,41,42,45,48';}
}
